# eric7.VirtualEnv.VirtualenvExecDialog

Module implementing the virtualenv execution dialog.

### Global Attributes

None

### Classes

VirtualenvExecDialog | Class implementing the virtualenv execution dialog.

### Functions

None

## VirtualenvExecDialog

Class implementing the virtualenv execution dialog.

This class starts a QProcess and displays a dialog that shows the output of the virtualenv or pyvenv process.

### Derived from

QDialog, Ui_VirtualenvExecDialog

### Class Attributes

None

### Class Methods

None

### Methods

VirtualenvExecDialog | Constructor
__finish | Private slot called when the process finished.
__logError | Private method to log an error.
__logOutput | Private method to log some output.
__nextAttempt | Private method to start another attempt.
__readStderr | Private slot to handle the readyReadStandardError signal.
__readStdout | Private slot to handle the readyReadStandardOutput signal.
__writeLogFile | Private method to write a log file to the virtualenv directory.
__writeScriptFile | Private method to write a script file to the virtualenv directory.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
start | Public slot to start the virtualenv command.

### Static Methods

None

#### VirtualenvExecDialog (Constructor)

VirtualenvExecDialog(configuration, venvManager, parent=None)

Constructor

configuration (dict)
  dictionary containing the configuration parameters as returned by the command configuration dialog
venvManager (VirtualenvManager)
  reference to the virtual environment manager
parent (QWidget)
  reference to the parent widget

#### VirtualenvExecDialog.__finish

__finish(exitCode, _exitStatus, giveUp=False)

Private slot called when the process finished.

It is called when the process finished or the user pressed the button.

exitCode (int)
  exit code of the process
_exitStatus (QProcess.ExitStatus)
  exit status of the process (unused)
giveUp (bool)
  flag indicating to not start another attempt

#### VirtualenvExecDialog.__logError

__logError(s)

Private method to log an error.

s (str)
  error string to log

#### VirtualenvExecDialog.__logOutput

__logOutput(s)

Private method to log some output.

s (str)
  output string to log

#### VirtualenvExecDialog.__nextAttempt

__nextAttempt()

Private method to start another attempt.

#### VirtualenvExecDialog.__readStderr

__readStderr()

Private slot to handle the readyReadStandardError signal.

It reads the error output of the process and inserts it into the error pane.

#### VirtualenvExecDialog.__readStdout

__readStdout()

Private slot to handle the readyReadStandardOutput signal.

It reads the output of the process, formats it and inserts it into the contents pane.

#### VirtualenvExecDialog.__writeLogFile

__writeLogFile()

Private method to write a log file to the virtualenv directory.

#### VirtualenvExecDialog.__writeScriptFile

__writeScriptFile()

Private method to write a script file to the virtualenv directory.

#### VirtualenvExecDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### VirtualenvExecDialog.start

start(arguments)

Public slot to start the virtualenv command.

arguments (list of str)
  commandline arguments for virtualenv/pyvenv program

Up